"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createCompression = void 0;
var _ContentCompressionPlugin = require("../../../plugins/ContentCompressionPlugin");
var _error = _interopRequireDefault(require("@webiny/error"));
const createCompressContent = plugins => {
  return async page => {
    const value = page.content;
    if (value?.compression) {
      return value;
    }
    const plugin = plugins.find(pl => pl.canCompress(value));
    if (!plugin) {
      throw new _error.default("There is no compression plugin to compress the page content.", "MISSING_COMPRESSION_PLUGIN", {
        id: page.id
      });
    }
    try {
      return await plugin.compress(value);
    } catch (ex) {
      console.log(`Error while compressing page "${page.id}" content: ${ex.message}`);
      return null;
    }
  };
};
const createDecompressContent = plugins => {
  return async page => {
    const value = page.content;
    /**
     * Possibly no compression on the content so lets return what ever is inside the content.
     */
    if (!value?.compression) {
      return value;
    }
    const plugin = plugins.find(pl => pl.canDecompress(value));
    if (!plugin) {
      throw new _error.default("There is no compression plugin to decompress the page content.", "MISSING_COMPRESSION_PLUGIN", {
        compression: value.compression,
        id: page.id
      });
    }
    try {
      return await plugin.decompress(value);
    } catch (ex) {
      console.log(`Error while decompressing page "${page.id}" content: ${ex.message}`);
      return null;
    }
  };
};
const createCompression = params => {
  const plugins = params.plugins.byType(_ContentCompressionPlugin.ContentCompressionPlugin.type).reverse();
  if (plugins.length === 0) {
    throw new _error.default("Missing content compression plugins. Must have at least one registered.", "MISSING_COMPRESSION_PLUGINS");
  }
  return {
    compressContent: createCompressContent(plugins),
    decompressContent: createDecompressContent(plugins)
  };
};
exports.createCompression = createCompression;

//# sourceMappingURL=compression.js.map